@@ -7,6 +7,7 @@ import abc
 import astropy
 from astropy.io.fits import Card
 from radio_beam import Beam, Beams
+import dask.array as da
 
 from . import wcs_utils
 from . import cube_utils
@@ -84,7 +85,7 @@ class HeaderMixinClass(object):
 
         # Preserve non-WCS information from previous header iteration
         header.update(wcsheader)
-        if self.unit == u.dimensionless_unscaled and 'BUNIT' in self._meta:
+        if self.unit == u.one and 'BUNIT' in self._meta:
             # preserve the BUNIT even though it's not technically valid
             # (Jy/Beam)
             header['BUNIT'] = self._meta['BUNIT']
@@ -576,15 +577,27 @@ class MultiBeamMixinClass(object):
         new_beam : radio_beam.Beam
             A new radio beam object that is the average of the unmasked beams
         """
+
+        use_dask = isinstance(self._data, da.Array)
+
         if mask == 'compute':
-            beam_mask = np.any(self.mask.include() &
-                               self.goodbeams_mask[:,None,None],
-                               axis=(1,2))
+            if use_dask:
+                # If we are dealing with dask arrays, we compute the beam
+                # mask once and for all since it is used multiple times in its
+                # entirety in the remainder of this method.
+                beam_mask = da.any(da.logical_and(self._mask_include,
+                                                  self.goodbeams_mask[:, None, None]),
+                                   axis=(1, 2))
+                beam_mask = self._compute(beam_mask)
+            else:
+                beam_mask = np.any(np.logical_and(self.mask.include(),
+                                                  self.goodbeams_mask[:, None, None]),
+                                   axis=(1, 2))
         else:
             if mask.ndim > 1:
-                beam_mask = mask & self.goodbeams_mask[:,None,None]
+                beam_mask = np.logical_and(mask, self.goodbeams_mask[:, None, None])
             else:
-                beam_mask = mask & self.goodbeams_mask
+                beam_mask = np.logical_and(mask, self.goodbeams_mask)
 
         # use private _beams here because the public one excludes the bad beams
         # by default
@@ -716,9 +729,9 @@ class MultiBeamMixinClass(object):
                                        self._wcs,
                                        shape=self._data.shape)
 
-        return self._new_thing_with(mask=self.mask & includemask,
+        return self._new_thing_with(mask=np.bitwise_and(self.mask, includemask),
                                     beam_threshold=threshold,
-                                    goodbeams_mask=self.goodbeams_mask & goodbeams,
+                                    goodbeams_mask=np.bitwise_and(self.goodbeams_mask, goodbeams),
                                    )
 
     def with_beams(self, beams, goodbeams_mask=None,):
@@ -776,4 +789,4 @@ class BeamMixinClass(object):
     def pixels_per_beam(self):
         return (self.beam.sr /
                 (astropy.wcs.utils.proj_plane_pixel_area(self.wcs) *
-                 u.deg**2)).to(u.dimensionless_unscaled).value
+                 u.deg**2)).to(u.one).value
