@@ -4,6 +4,7 @@ import warnings
 
 import numpy as np
 from numpy.ma.core import nomask
+import dask.array as da
 
 from astropy import convolution
 from astropy import units as u
@@ -11,9 +12,10 @@ from astropy import wcs
 #from astropy import log
 from astropy.io.fits import Header, HDUList, PrimaryHDU, BinTableHDU, FITS_rec
 from radio_beam import Beam, Beams
+from astropy.io.registry import UnifiedReadWriteMethod
 
-from .io.core import determine_format
 from . import spectral_axis
+from .io.core import LowerDimensionalObjectWrite
 from .utils import SliceWarning, BeamWarning, SmoothingWarning, FITSWarning
 from .cube_utils import convert_bunit
 from . import wcs_utils
@@ -27,8 +29,6 @@ from .base_class import (BaseNDClass, SpectralAxisMixinClass,
 from . import cube_utils
 
 __all__ = ['LowerDimensionalObject', 'Projection', 'Slice', 'OneDSpectrum']
-
-
 class LowerDimensionalObject(u.Quantity, BaseNDClass, HeaderMixinClass):
     """
     Generic class for 1D and 2D objects.
@@ -47,40 +47,10 @@ class LowerDimensionalObject(u.Quantity, BaseNDClass, HeaderMixinClass):
 
         return hdu
 
-    def write(self, filename, format=None, overwrite=False):
-        """
-        Write the lower dimensional object to a file.
-
-        Parameters
-        ----------
-        filename : str
-            The path to write the file to
-        format : str
-            The kind of file to write. (Currently limited to 'fits')
-        overwrite : bool
-            If True, overwrite ``filename`` if it exists
-        """
-        if format is None:
-            format = determine_format(filename)
-        if format == 'fits':
-            # Spectra may have HDUList objects instead of HDUs because they
-            # have a beam table attached, so we want to try that first
-            # (a more elegant way to write this might be to do "self._hdu_general.write"
-            # and create a property `self._hdu_general` that selects the right one...)
-            if hasattr(self, 'hdulist'):
-                try:
-                    self.hdulist.writeto(filename, overwrite=overwrite)
-                except TypeError:
-                    self.hdulist.writeto(filename, clobber=overwrite)
-            elif hasattr(self, 'hdu'):
-                try:
-                    self.hdu.writeto(filename, overwrite=overwrite)
-                except TypeError:
-                    self.hdu.writeto(filename, clobber=overwrite)
-        else:
-            raise ValueError("Unknown format '{0}' - the only available "
-                             "format at this time is 'fits'")
+    def read(self, *args, **kwargs):
+        raise NotImplementedError()
 
+    write = UnifiedReadWriteMethod(LowerDimensionalObjectWrite)
 
     def __getslice__(self, start, end, increment=None):
         # I don't know why this is needed, but apparently one of the inherited
@@ -491,7 +461,8 @@ class Projection(LowerDimensionalObject, SpatialCoordMixinClass,
         if filename is not None:
             self.figure.savefig(filename)
 
-    def convolve_to(self, beam, convolve=convolution.convolve_fft):
+    def convolve_to(self, beam, convolve=convolution.convolve_fft,
+                    **kwargs):
         """
         Convolve the image to a specified beam.
 
@@ -527,7 +498,8 @@ class Projection(LowerDimensionalObject, SpatialCoordMixinClass,
             beam.deconvolve(self.beam).as_kernel(pixscale)
 
         newdata = convolve(self.value, convolution_kernel,
-                           normalize_kernel=True)
+                           normalize_kernel=True,
+                           **kwargs)
 
         self = Projection(newdata, unit=self.unit, wcs=self.wcs,
                           meta=self.meta, header=self.header,
@@ -770,7 +742,7 @@ class BaseOneDSpectrum(LowerDimensionalObject, MaskableArrayMixinClass,
         """
 
         if self._wcs is None:
-            spec_axis = np.arange(self.size) * u.dimensionless_unscaled
+            spec_axis = np.arange(self.size) * u.one
         else:
             spec_axis = self.wcs.wcs_pix2world(np.arange(self.size), 0)[0] * \
                 u.Unit(self.wcs.wcs.cunit[0])
@@ -857,6 +829,8 @@ class BaseOneDSpectrum(LowerDimensionalObject, MaskableArrayMixinClass,
             if self._mask is not nomask:
                 # Kind of a hack; this is probably inefficient
                 bad = self._mask.exclude()[key]
+                if isinstance(bad, da.Array):
+                    bad = bad.compute()
                 new_qty[bad] = np.nan
             return new_qty
 
