@@ -1,6 +1,7 @@
 from __future__ import print_function, absolute_import, division
 
 import abc
+import uuid
 import warnings
 import tempfile
 
@@ -8,6 +9,8 @@ from six.moves import zip
 import numpy as np
 from numpy.lib.stride_tricks import as_strided
 
+import dask.array as da
+
 from astropy.wcs import InconsistentAxisTypesError
 from astropy.io import fits
 
@@ -157,7 +160,7 @@ class MaskBase(object):
         return self._exclude(data=data, wcs=wcs, view=view)
 
     def _exclude(self, data=None, wcs=None, view=()):
-        return ~self._include(data=data, wcs=wcs, view=view)
+        return np.logical_not(self._include(data=data, wcs=wcs, view=view))
 
     def any(self):
         return np.any(self.exclude())
@@ -182,7 +185,17 @@ class MaskBase(object):
         -----
         This is an internal method used by :class:`SpectralCube`.
         """
-        return data[view][self.include(data=data, wcs=wcs, view=view)]
+
+        mask = self.include(data=data, wcs=wcs, view=view)
+
+        # Workaround for https://github.com/dask/dask/issues/6089
+        if isinstance(data, da.Array) and not isinstance(mask, da.Array):
+            mask = da.asarray(mask, name=str(uuid.uuid4()))
+
+        # if not isinstance(data, da.Array) and isinstance(mask, da.Array):
+        #     mask = mask.compute()
+
+        return data[view][mask]
 
     def _filled(self, data, wcs=None, fill=np.nan, view=(), use_memmap=False,
                 **kwargs):
@@ -223,8 +236,8 @@ class MaskBase(object):
             sliced_data = data[view].astype(dt)
 
         ex = self.exclude(data=data, wcs=wcs, view=view, **kwargs)
-        sliced_data[ex] = fill
-        return sliced_data
+
+        return np.ma.masked_array(sliced_data, mask=ex).filled(fill)
 
     def __and__(self, other):
         return CompositeMask(self, other, operation='and')
@@ -322,7 +335,7 @@ class InvertedMask(MaskBase):
         return self._mask.shape
 
     def _include(self, data=None, wcs=None, view=()):
-        return ~self._mask.include(data=data, wcs=wcs, view=view)
+        return np.logical_not(self._mask.include(data=data, wcs=wcs, view=view))
 
     def __getitem__(self, view):
         return InvertedMask(self._mask[view])
@@ -404,11 +417,11 @@ class CompositeMask(MaskBase):
         result_mask_1 = self._mask1._include(data=data, wcs=wcs, view=view)
         result_mask_2 = self._mask2._include(data=data, wcs=wcs, view=view)
         if self._operation == 'and':
-            return result_mask_1 & result_mask_2
+            return np.bitwise_and(result_mask_1, result_mask_2)
         elif self._operation == 'or':
-            return result_mask_1 | result_mask_2
+            return np.bitwise_or(result_mask_1, result_mask_2)
         elif self._operation == 'xor':
-            return result_mask_1 ^ result_mask_2
+            return np.bitwise_xor(result_mask_1, result_mask_2)
         else:
             raise ValueError("Operation '{0}' not supported".format(self._operation))
 
@@ -532,11 +545,11 @@ class BooleanArrayMask(MaskBase):
 
     def _include(self, data=None, wcs=None, view=()):
         result_mask = self._mask[view]
-        return result_mask if self._mask_type == 'include' else ~result_mask
+        return result_mask if self._mask_type == 'include' else np.logical_not(result_mask)
 
     def _exclude(self, data=None, wcs=None, view=()):
         result_mask = self._mask[view]
-        return result_mask if self._mask_type == 'exclude' else ~result_mask
+        return result_mask if self._mask_type == 'exclude' else np.logical_not(result_mask)
 
     @property
     def shape(self):
