@@ -1,10 +1,14 @@
 from __future__ import print_function, absolute_import, division
 
+import numpy as np
+
 from astropy import wcs
 from astropy import units as u
 from astropy import constants
 import warnings
 
+from .utils import ExperimentalImplementationWarning
+
 def _parse_velocity_convention(vc):
     if vc in (u.doppler_radio, 'radio', 'RADIO', 'VRAD', 'F', 'FREQ'):
         return u.doppler_radio
@@ -151,6 +155,38 @@ def get_rest_value_from_wcs(mywcs):
         ref_value = mywcs.wcs.restwav*u.m
         return ref_value
 
+# Velocity/frequency equivalencies that are not present in astropy core.
+# Ref: https://casa.nrao.edu/casadocs/casa-5-1.2/reference-material/spectral-frames
+
+
+def doppler_z(restfreq):
+    restfreq = restfreq.to_value("GHz")
+    return [(u.GHz, u.km / u.s,
+            lambda x: (restfreq - x) / x,
+            lambda x: restfreq / (1 + x)
+             )]
+
+
+def doppler_beta(restfreq):
+    restfreq = restfreq.to_value("GHz")
+    return [(u.GHz, u.km / u.s,
+            lambda x: constants.si.c.to_value('km/s') * ((1 - ((x / restfreq) ** 2)) /
+                                                         (1 + ((x / restfreq) ** 2))),
+            lambda x: restfreq * np.sqrt((constants.si.c.to_value("km/s") - x) /
+                                         (x + constants.si.c.to_value("km/s")))
+             )]
+
+
+def doppler_gamma(restfreq):
+    restfreq = restfreq.to_value("GHz")
+    return [(u.GHz, u.km / u.s,
+            lambda x: constants.si.c.to_value("km/s") * ((1 + (x / restfreq) ** 2) /
+                                                         (2 * x / restfreq)),
+            lambda x: restfreq * (x / constants.si.c.to_value("km/s") +
+                                  np.sqrt((x / constants.si.c.to_value("km/s")) ** 2 - 1))
+             )]
+
+
 def convert_spectral_axis(mywcs, outunit, out_ctype, rest_value=None):
     """
     Convert a spectral axis from its unit to a specified out unit with a given output
@@ -241,7 +277,9 @@ def convert_spectral_axis(mywcs, outunit, out_ctype, rest_value=None):
 
     if in_spec_ctype == 'AWAV':
         warnings.warn("Support for air wavelengths is experimental and only "
-                      "works in the forward direction (air->vac, not vac->air).")
+                      "works in the forward direction (air->vac, not vac->air).",
+                      ExperimentalImplementationWarning
+                     )
         cdelt_in = air_to_vac_deriv(crval_in) * cdelt_in
         crval_in = air_to_vac(crval_in)
         in_spec_ctype = 'WAVE'
