@@ -3,14 +3,18 @@ from __future__ import print_function, absolute_import, division
 import numpy as np
 from astropy.io import fits as pyfits
 from astropy import units as u
-from ..io import class_lmv, fits
-from .. import SpectralCube, StokesSpectralCube
+from .. import StokesSpectralCube
 from ..lower_dimensional_structures import (OneDSpectrum,
                                             VaryingResolutionOneDSpectrum)
 from . import path
 
 from radio_beam import Beam
 
+
+from .. import SpectralCube, VaryingResolutionSpectralCube
+from ..dask_spectral_cube import DaskSpectralCube
+
+
 def test_lmv_fits():
     c1 = SpectralCube.read(path('example_cube.fits'))
     c2 = SpectralCube.read(path('example_cube.lmv'))
@@ -23,40 +27,60 @@ def test_lmv_fits():
     # should also be able to do this, but it is again false:
     #assert c1.wcs==c2.wcs
 
-def test_3d_4d_stokes():
-    f3 = pyfits.open(path('adv.fits'))
-    f4 = pyfits.open(path('advs.fits'))
+
+def test_3d_4d_stokes(data_adv, data_advs, use_dask):
+    f3 = pyfits.open(data_adv)
+    f4 = pyfits.open(data_advs)
     f3b = pyfits.PrimaryHDU(data=f3[0].data, header=f4[0].header)
 
-    c1 = SpectralCube.read(f3)
-    c2 = SpectralCube.read(f4)
-    c3 = SpectralCube.read(f3b)
+    c1 = SpectralCube.read(f3, use_dask=use_dask)
+    c2 = SpectralCube.read(f4, use_dask=use_dask)
+    c3 = SpectralCube.read(f3b, use_dask=use_dask)
 
     assert c1.shape == c3.shape
     # c2 has a different shape on disk...
+    f3.close()
+    f4.close()
 
-def test_4d_stokes():
-    f = pyfits.open(path('advs.fits'))
-    c = StokesSpectralCube.read(f)
+
+def test_4d_stokes(data_advs, use_dask):
+    f = pyfits.open(data_advs)
+    c = StokesSpectralCube.read(f, use_dask=use_dask)
     assert isinstance(c, StokesSpectralCube)
+    if use_dask:
+        assert isinstance(c.I, DaskSpectralCube)
+    else:
+        assert isinstance(c.I, SpectralCube)
+    f.close()
 
-def test_3d_beams():
-    c = SpectralCube.read(path('vda_beams.fits'))
-    np.testing.assert_almost_equal(c.beams[0].major.value, 0.4)
-    np.testing.assert_almost_equal(c.beams[0].minor.value, 0.1)
 
-def test_4d_beams():
-    c = SpectralCube.read(path('sdav_beams.fits'))
+def test_4d_stokes_read_3d(data_adv, use_dask):
+    # Regression test for a bug that caused StokesSpectralCube.read to not work
+    # correctly when reading in a 3D FITS file.
+    f = pyfits.open(data_adv)
+    c = StokesSpectralCube.read(f, use_dask=use_dask)
+    assert isinstance(c, StokesSpectralCube)
+    f.close()
+
+
+def test_3d_beams(data_vda_beams, use_dask):
+    c = SpectralCube.read(data_vda_beams, use_dask=use_dask)
     np.testing.assert_almost_equal(c.beams[0].major.value, 0.4)
     np.testing.assert_almost_equal(c.beams[0].minor.value, 0.1)
 
 
-def test_3d_beams_roundtrip():
-    c = SpectralCube.read(path('vda_beams.fits'))
+def test_4d_beams(data_sdav_beams, use_dask):
+    c = SpectralCube.read(data_sdav_beams, use_dask=use_dask)
     np.testing.assert_almost_equal(c.beams[0].major.value, 0.4)
     np.testing.assert_almost_equal(c.beams[0].minor.value, 0.1)
-    c.write(path('vda_beams_out.fits'))
-    c2 = SpectralCube.read(path('vda_beams_out.fits'))
+
+
+def test_3d_beams_roundtrip(tmpdir, data_vda_beams, use_dask):
+    c = SpectralCube.read(data_vda_beams, use_dask=use_dask)
+    np.testing.assert_almost_equal(c.beams[0].major.value, 0.4)
+    np.testing.assert_almost_equal(c.beams[0].minor.value, 0.1)
+    c.write(tmpdir.join('vda_beams_out.fits').strpath)
+    c2 = SpectralCube.read(tmpdir.join('vda_beams_out.fits').strpath, use_dask=use_dask)
 
     # assert c==c2 # this is not implemented?
     assert np.all(c.filled_data[:] == c2.filled_data[:])
@@ -66,13 +90,13 @@ def test_3d_beams_roundtrip():
     np.testing.assert_almost_equal(c2.beams[0].minor.value, 0.1)
 
 
-def test_4d_beams_roundtrip():
+def test_4d_beams_roundtrip(tmpdir, data_sdav_beams, use_dask):
     # not sure if 4d can round-trip...
-    c = SpectralCube.read(path('sdav_beams.fits'))
+    c = SpectralCube.read(data_sdav_beams, use_dask=use_dask)
     np.testing.assert_almost_equal(c.beams[0].major.value, 0.4)
     np.testing.assert_almost_equal(c.beams[0].minor.value, 0.1)
-    c.write(path('sdav_beams_out.fits'))
-    c2 = SpectralCube.read(path('sdav_beams_out.fits'))
+    c.write(tmpdir.join('sdav_beams_out.fits').strpath)
+    c2 = SpectralCube.read(tmpdir.join('sdav_beams_out.fits').strpath, use_dask=use_dask)
 
     # assert c==c2 # this is not implemented?
     assert np.all(c.filled_data[:] == c2.filled_data[:])
@@ -81,17 +105,20 @@ def test_4d_beams_roundtrip():
     np.testing.assert_almost_equal(c2.beams[0].major.value, 0.4)
     np.testing.assert_almost_equal(c2.beams[0].minor.value, 0.1)
 
-def test_1d():
-    hdu = pyfits.open(path('5_spectral.fits'))[0]
+def test_1d(data_5_spectral):
+    hdul = pyfits.open(data_5_spectral)
+    hdu = hdul[0]
     spec = OneDSpectrum.from_hdu(hdu)
 
     np.testing.assert_almost_equal(spec, np.arange(5, dtype='float'))
+    hdul.close()
 
-def test_1d_beams():
-    hdu = pyfits.open(path('5_spectral_beams.fits'))
+def test_1d_beams(data_5_spectral_beams, use_dask):
+    hdu = pyfits.open(data_5_spectral_beams)
     spec = OneDSpectrum.from_hdu(hdu)
 
     np.testing.assert_almost_equal(spec, np.arange(5, dtype='float'))
     assert isinstance(spec, VaryingResolutionOneDSpectrum)
     assert hasattr(spec, 'beams')
     assert len(spec.beams) == 5
+    hdu.close()
