@@ -26,9 +26,9 @@ except ImportError:
     scipyOK = False
 
 
-def test_subcube():
+def test_subcube(data_advs, use_dask):
 
-    cube, data = cube_and_raw('advs.fits')
+    cube, data = cube_and_raw(data_advs, use_dask=use_dask)
 
     sc1 = cube.subcube(xlo=1, xhi=3)
     sc2 = cube.subcube(xlo=24.06269*u.deg, xhi=24.06206*u.deg)
@@ -61,9 +61,9 @@ def test_subcube():
 @pytest.mark.parametrize('regfile',
                          ('255-fk5.reg', '255-pixel.reg'),
                         )
-def test_ds9region_255(regfile):
+def test_ds9region_255(regfile, data_255, use_dask):
     # specific test for correctness
-    cube, data = cube_and_raw('255.fits')
+    cube, data = cube_and_raw(data_255, use_dask=use_dask)
 
     shapelist = regions.read_ds9(path(regfile))
 
@@ -77,6 +77,7 @@ def test_ds9region_255(regfile):
 @pytest.mark.skipif('not REGIONS_GT_03', reason='regions version should be >= 0.3')
 @pytest.mark.parametrize(('regfile', 'result'),
                              (('fk5.reg', (slice(None), 1, 1)),
+                              ('fk5_twoboxes.reg', (slice(None), 1, 1)),
                               ('image.reg', (slice(None), 1, slice(None))),
                               (
                               'partial_overlap_image.reg', (slice(None), 1, 1)),
@@ -84,16 +85,14 @@ def test_ds9region_255(regfile):
                               ('partial_overlap_fk5.reg', (slice(None), 1, 1)),
                               ('no_overlap_fk5.reg', ValueError),
                               ))
-def test_ds9region_new(regfile, result):
-    cube, data = cube_and_raw('adv.fits')
+def test_ds9region_new(regfile, result, data_adv, use_dask):
+    cube, data = cube_and_raw(data_adv, use_dask=use_dask)
 
     regionlist = regions.read_ds9(path(regfile))
 
     if isinstance(result, type) and issubclass(result, Exception):
-        with pytest.raises(result) as exc:
+        with pytest.raises(result):
             sc = cube.subcube_from_regions(regionlist)
-        # this assertion is redundant, I think...
-        assert exc.errisinstance(result)
     else:
         sc = cube.subcube_from_regions(regionlist)
         scsum = sc.sum()
@@ -113,8 +112,8 @@ def test_ds9region_new(regfile, result):
 @pytest.mark.skipif('not scipyOK', reason='Could not import scipy')
 @pytest.mark.skipif('not regionsOK', reason='Could not import regions')
 @pytest.mark.skipif('not REGIONS_GT_03', reason='regions version should be >= 0.3')
-def test_regions_spectral():
-    cube, data = cube_and_raw('adv.fits')
+def test_regions_spectral(data_adv, use_dask):
+    cube, data = cube_and_raw(data_adv, use_dask=use_dask)
     rf_cube = get_rest_value_from_wcs(cube.wcs).to("GHz",
                                                          equivalencies=u.spectral())
 
